==> librepcb-1.0.0-source.zip: librepcb-1.0.0/AUTHORS.md <==
# Authors

Many people have contributed to LibrePCB. This is an attempt to list them all.

If you are a contributor and your name is not listed here, feel free to add
yourself by creating a pull request (see [CONTRIBUTING.md](CONTRIBUTING.md)).

## Main Authors
- U. Bruhin ([@ubruhin](https://github.com/ubruhin))

## Contributors
- Danilo Bargen ([@dbrgn](https://github.com/dbrgn))
- Raphael Nestler ([@rnestler](https://github.com/rnestler))
- Lucas ([@5n8ke](https://github.com/5n8ke))
- Eduardo Sánchez Muñoz ([@eduardosm](https://github.com/eduardosm))
- Roman V ([@NZSmartie](https://github.com/NZSmartie))
- [@kliment](https://github.com/kliment)
- [@Luz](https://github.com/Luz)
- [@0xB767B](https://github.com/0xB767B)
- Alexander Wilms ([@Alexander-Wilms](https://github.com/Alexander-Wilms))
- Jeff Wheeler ([@jeffwheeler](https://github.com/jeffwheeler))
- Christian Gwerder ([@chrisgwerder](https://github.com/chrisgwerder))
- Florian Bruhin ([@The-Compiler](https://github.com/The-Compiler))
- [@NiFa18](https://github.com/NiFa18)
- Răzvan Cojocaru ([@rzvncj](https://github.com/rzvncj))
- Rob Weber ([@robbawebba](https://github.com/robbawebba))
- [@melak](https://github.com/melak)
- Troy Denton ([@trdenton](https://github.com/trdenton))
- Tubbles ([@Tubbles](https://github.com/Tubbles))
- [@bjaminn](https://github.com/bjaminn)
- Federico Ceratto ([@FedericoCeratto](https://github.com/FedericoCeratto))
- Javier Sánchez Parra ([@javsanpar](https://github.com/javsanpar))
- Allan Nordhøy ([@comradekingu](https://github.com/comradekingu))
- David Lamparter ([@eqvinox](https://github.com/eqvinox))
- Ilia Sharin ([@alfishe](https://github.com/alfishe))
- Josua Schmid ([@schmijos](https://github.com/schmijos))
- [@mexchip](https://github.com/mexchip)
- Nao Pross ([@NaoPross](https://github.com/NaoPross))
- Petros S ([@Petross404](https://github.com/Petross404))
- Raphael Theiler ([@ammoniak](https://github.com/ammoniak))
- Thomas Fischl ([@EmbedME](https://github.com/EmbedME))
- Tobias Backer Dirks ([@omgitsaheadcrab](https://github.com/omgitsaheadcrab))
- [@freddii](https://github.com/freddii)
- [@hephaisto](https://github.com/hephaisto)
- [@luzpaz](https://github.com/luzpaz)
- [@masondb](https://github.com/masondb)
- [@picknick-](https://github.com/picknick-)
- [@probonopd](https://github.com/probonopd)
- yuri@FreeBSD ([@yurivict](https://github.com/yurivict))

==> librepcb-1.3.0-source.zip: librepcb-1.3.0/AUTHORS.md <==
# Authors

Many people have contributed to LibrePCB. This is an attempt to list them all.

If you are a contributor and your name is not listed here, feel free to add
yourself by creating a pull request (see [CONTRIBUTING.md](CONTRIBUTING.md)).

## Main Authors
- U. Bruhin ([@ubruhin](https://github.com/ubruhin))

## Contributors
- Danilo Bargen ([@dbrgn](https://github.com/dbrgn))
- Raphael Nestler ([@rnestler](https://github.com/rnestler))
- Lucas ([@5n8ke](https://github.com/5n8ke))
- Frantisek Burian ([@BuFran](https://github.com/BuFran))
- Eduardo Sánchez Muñoz ([@eduardosm](https://github.com/eduardosm))
- [@Luz](https://github.com/Luz)
- Roman V ([@NZSmartie](https://github.com/NZSmartie))
- [@kliment](https://github.com/kliment)
- [@0xB767B](https://github.com/0xB767B)
- Federico Ceratto ([@FedericoCeratto](https://github.com/FedericoCeratto))
- Jeff Wheeler ([@jeffwheeler](https://github.com/jeffwheeler))
- [@luzpaz](https://github.com/luzpaz)
- Javier Sánchez Parra ([@javsanpar](https://github.com/javsanpar))
- [@bjaminn](https://github.com/bjaminn)
- Tubbles ([@Tubbles](https://github.com/Tubbles))
- Troy Denton ([@trdenton](https://github.com/trdenton))
- [@melak](https://github.com/melak)
- Rob Weber ([@robbawebba](https://github.com/robbawebba))
- Răzvan Cojocaru ([@rzvncj](https://github.com/rzvncj))
- [@NiFa18](https://github.com/NiFa18)
- Florian Bruhin ([@The-Compiler](https://github.com/The-Compiler))
- Christian Gwerder ([@chrisgwerder](https://github.com/chrisgwerder))
- yuri@FreeBSD ([@yurivict](https://github.com/yurivict))
- [@probonopd](https://github.com/probonopd)
- [@picknick-](https://github.com/picknick-)
- [@mi4code](https://github.com/mi4code)
- [@hephaisto](https://github.com/hephaisto)
- [@freddii](https://github.com/freddii)
- Tobias Backer Dirks ([@omgitsaheadcrab](https://github.com/omgitsaheadcrab))
- Thomas Fischl ([@EmbedME](https://github.com/EmbedME))
- Raphael Theiler ([@ammoniak](https://github.com/ammoniak))
- Petros S ([@Petross404](https://github.com/Petross404))
- Nao Pross ([@NaoPross](https://github.com/NaoPross))
- [@mexchip](https://github.com/mexchip)
- Josua Schmid ([@schmijos](https://github.com/schmijos))
- Ilia Sharin ([@alfishe](https://github.com/alfishe))
- David Lamparter ([@eqvinox](https://github.com/eqvinox))
- Connor Slade ([@connorslade](https://github.com/connorslade))
- Allan Nordhøy ([@comradekingu](https://github.com/comradekingu))
- Alexander Wilms
